@@ -1,7 +1,7 @@
 package Factory::Sub;
 use 5.006; use strict; use warnings;
 use Import::Into; use Carp qw/croak/; use Coerce::Types::Standard qw//;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use overload 
 	"&{}" => sub {my $self = shift; sub { $self->call(@_) }},
@@ -37,7 +37,7 @@ sub call {
 						&& scalar @{$factory->[$i]->{coercion}->{type_coercion_map}} 
 							? $factory->[$i]->coerce($factory_params[$i])
 							: $factory_params[$i]
-				) } or next FACTORY;
+				); defined $factory_params[$i] } or next FACTORY;
 			}
 			return $factory->[-1]->(@factory_params);
 		}
@@ -64,7 +64,7 @@ Factory::Sub - Generate a factory of subs
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
